AsyncIo

Struct AsyncIo 

pub struct AsyncIo<T: ?Sized> { /* private fields */ }
Adapter from ZMux async stream traits to standard async I/O traits.

With the tokio-io feature this type implements tokio::io::AsyncRead and/or tokio::io::AsyncWrite. With the futures-io feature it implements futures_io::AsyncRead and/or futures_io::AsyncWrite.

Implementations

Source

impl<T> AsyncIo<T>
where T: Send + Sync + 'static,

pub fn new(stream: T) -> Self

Wraps an owned async ZMux stream behind standard async I/O traits.

Source

impl<T: ?Sized> AsyncIo<T>

pub fn from_arc(inner: Arc<T>) -> Self

Wraps an already shared async ZMux stream.

pub fn get_ref(&self) -> &T

Borrows the wrapped stream.

pub fn as_arc(&self) -> &Arc<T>

Borrows the shared owner.

pub fn into_inner(self) -> Arc<T>

Returns the shared owner of the wrapped stream.

pub fn read_chunk_size(&self) -> usize

Returns the maximum read buffer used per poll operation.

pub fn set_read_chunk_size(&mut self, size: usize)

Sets the maximum read buffer used per poll operation.

pub fn write_chunk_size(&self) -> usize

Returns the maximum write buffer copied per poll operation.

pub fn set_write_chunk_size(&mut self, size: usize)

Sets the maximum write buffer copied per poll operation.