pub type BoxDuplexStream = Box<dyn DuplexStreamHandle>;Expand description
Boxed bidirectional stream trait object used by the native blocking API.
Aliased Type
pub struct BoxDuplexStream(/* private fields */);pub type BoxDuplexStream = Box<dyn DuplexStreamHandle>;Boxed bidirectional stream trait object used by the native blocking API.
pub struct BoxDuplexStream(/* private fields */);