pub type BoxSendStream = Box<dyn SendStreamHandle>;Expand description
Boxed send-only stream trait object used by the native blocking API.
Aliased Type
pub struct BoxSendStream(/* private fields */);pub type BoxSendStream = Box<dyn SendStreamHandle>;Boxed send-only stream trait object used by the native blocking API.
pub struct BoxSendStream(/* private fields */);